@@ -90,28 +90,12 @@ _pango_cairo_update_context (cairo_t      *cr,
   cairo_matrix_t cairo_matrix;
   cairo_surface_t *target;
   PangoMatrix pango_matrix;
-  const PangoMatrix *layout_matrix, identity_matrix = PANGO_MATRIX_INIT;
+  const PangoMatrix *current_matrix, identity_matrix = PANGO_MATRIX_INIT;
+  const cairo_font_options_t *merged_options;
   gboolean changed = FALSE;
 
   info = get_context_info (context, TRUE);
 
-  cairo_get_matrix (cr, &cairo_matrix);
-  pango_matrix.xx = cairo_matrix.xx;
-  pango_matrix.yx = cairo_matrix.yx;
-  pango_matrix.xy = cairo_matrix.xy;
-  pango_matrix.yy = cairo_matrix.yy;
-  pango_matrix.x0 = cairo_matrix.x0;
-  pango_matrix.y0 = cairo_matrix.y0;
-
-  layout_matrix = pango_context_get_matrix (context);
-  if (!layout_matrix)
-    layout_matrix = &identity_matrix;
-
-  if (0 != memcmp (&pango_matrix, layout_matrix, sizeof (pango_matrix)))
-    changed = TRUE;
-
-  pango_context_set_matrix (context, &pango_matrix);
-
 
   target = cairo_get_target (cr);
 
@@ -136,6 +120,30 @@ _pango_cairo_update_context (cairo_t      *cr,
       info->merged_options = NULL;
     }
 
+  merged_options = _pango_cairo_context_get_merged_font_options (context);
+
+
+  cairo_get_matrix (cr, &cairo_matrix);
+  pango_matrix.xx = cairo_matrix.xx;
+  pango_matrix.yx = cairo_matrix.yx;
+  pango_matrix.xy = cairo_matrix.xy;
+  pango_matrix.yy = cairo_matrix.yy;
+  pango_matrix.x0 = cairo_matrix.x0;
+  pango_matrix.y0 = cairo_matrix.y0;
+
+  current_matrix = pango_context_get_matrix (context);
+  if (!current_matrix)
+    current_matrix = &identity_matrix;
+
+  /* layout is matrix-independent if metrics-hinting is off.
+   * also ignore matrix translation offsets */
+  if ((cairo_font_options_get_hint_metrics (merged_options) != CAIRO_HINT_METRICS_OFF) &&
+      (0 != memcmp (&pango_matrix, current_matrix, 4 * sizeof (double))))
+    changed = TRUE;
+
+  pango_context_set_matrix (context, &pango_matrix);
+
+
   return changed;
 }
 
@@ -215,6 +223,8 @@ pango_cairo_context_get_resolution (PangoContext *context)
  * Sets the font options used when rendering text with this context.
  * These options override any options that pango_cairo_update_context()
  * derives from the target surface.
+ *
+ * Since: 1.10
  */
 void
 pango_cairo_context_set_font_options (PangoContext               *context,
@@ -252,6 +262,8 @@ pango_cairo_context_set_font_options (PangoContext               *context,
  * Return value: the font options previously set on the context, or %NULL
  *   if no options have been set. This value is owned by the context
  *   and must not be modified or freed.
+ *
+ * Since: 1.10
  **/
 G_CONST_RETURN cairo_font_options_t *
 pango_cairo_context_get_font_options (PangoContext *context)
@@ -374,6 +386,39 @@ pango_cairo_context_get_shape_renderer (PangoContext                *context,
     }
 }
 
+/**
+ * pango_cairo_create_context:
+ * @cr: a Cairo context
+ *
+ * Creates a context object set up to match the current transformation
+ * and target surface of the Cairo context.  This context can then be
+ * used to create a layout using pango_layout_new().
+ *
+ * This function is a convenience function that creates a context using
+ * the default font map, then updates it to @cr.  If you just need to
+ * create a layout for use with @cr and do not need to access #PangoContext
+ * directly, you can use pango_cairo_create_layout() instead.
+ *
+ * Return value: the newly created #PangoContext. Free with
+ *   g_object_unref().
+ *
+ * Since: 1.22
+ **/
+PangoContext *
+pango_cairo_create_context (cairo_t *cr)
+{
+  PangoFontMap *fontmap;
+  PangoContext *context;
+
+  g_return_val_if_fail (cr != NULL, NULL);
+
+  fontmap = pango_cairo_font_map_get_default ();
+  context = pango_cairo_font_map_create_context ((PangoCairoFontMap *) (fontmap));
+  pango_cairo_update_context (cr, context);
+
+  return context;
+}
+
 /**
  * pango_cairo_create_layout:
  * @cr: a Cairo context
@@ -398,17 +443,13 @@ pango_cairo_context_get_shape_renderer (PangoContext                *context,
 PangoLayout *
 pango_cairo_create_layout  (cairo_t *cr)
 {
-  PangoFontMap *fontmap;
   PangoContext *context;
   PangoLayout *layout;
 
   g_return_val_if_fail (cr != NULL, NULL);
 
-  fontmap = pango_cairo_font_map_get_default ();
-  context = pango_cairo_font_map_create_context ((PangoCairoFontMap *) (fontmap));
+  context = pango_cairo_create_context (cr);
   layout = pango_layout_new (context);
-
-  pango_cairo_update_context (cr, context);
   g_object_unref (context);
 
   return layout;
